@@ -16,6 +16,7 @@
 import mock
 from osc_lib.tests import utils
 
+from tripleoclient import plugin
 from tripleoclient.tests import fakes
 
 
@@ -47,7 +48,10 @@ class TestOvercloudUpgradePrepare(utils.TestCommand):
         self.app.client_manager.auth_ref = mock.Mock(auth_token="TOKEN")
         self.app.client_manager.baremetal = mock.Mock()
         self.app.client_manager.orchestration = mock.Mock()
-        self.app.client_manager.tripleoclient = FakeClientWrapper()
+        tc = self.app.client_manager.tripleoclient = FakeClientWrapper()
+        tc.create_mistral_context = plugin.ClientWrapper(
+            instance=fakes.FakeInstanceData
+        ).create_mistral_context
         workflow = execution = mock.Mock()
         execution.id = "IDID"
         workflow.executions.create.return_value = execution
